svn commit: samba r21395 - in branches/SAMBA_4_0/source/dsdb/samdb/ldb_modules: .

metze at samba.org metze at samba.org
Fri Feb 16 17:36:58 GMT 2007


Author: metze
Date: 2007-02-16 17:36:58 +0000 (Fri, 16 Feb 2007)
New Revision: 21395

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=21395

Log:
fix comments

metze
Modified:
   branches/SAMBA_4_0/source/dsdb/samdb/ldb_modules/password_hash.c


Changeset:
Modified: branches/SAMBA_4_0/source/dsdb/samdb/ldb_modules/password_hash.c
===================================================================
--- branches/SAMBA_4_0/source/dsdb/samdb/ldb_modules/password_hash.c	2007-02-16 17:25:54 UTC (rev 21394)
+++ branches/SAMBA_4_0/source/dsdb/samdb/ldb_modules/password_hash.c	2007-02-16 17:36:58 UTC (rev 21395)
@@ -56,7 +56,7 @@
  * Once this is done (which could update anything at all), we
  * calculate the password hashes.
  *
  * This function must not only update the ntPwdHash, lmPwdHash and
  * krb5Key fields, it must also atomicly increment the
  * msDS-KeyVersionNumber.  We should be in a transaction, so all this
  * should be quite safe...
@@ -625,11 +625,11 @@
 	}
 
 	if (ntAttr && (ntAttr->num_values > 1)) {
-		ldb_set_errstring(module->ldb, "mupltiple values for lmPwdHash not allowed!\n");
+		ldb_set_errstring(module->ldb, "mupltiple values for unicodePwd not allowed!\n");
 		return LDB_ERR_CONSTRAINT_VIOLATION;
 	}
 	if (lmAttr && (lmAttr->num_values > 1)) {
-		ldb_set_errstring(module->ldb, "mupltiple values for lmPwdHash not allowed!\n");
+		ldb_set_errstring(module->ldb, "mupltiple values for dBCSPwd not allowed!\n");
 		return LDB_ERR_CONSTRAINT_VIOLATION;
 	}
 
@@ -639,11 +639,11 @@
 	}
 
 	if (ntAttr && (ntAttr->num_values == 0)) {
-		ldb_set_errstring(module->ldb, "lmPwdHash must have a value!\n");
+		ldb_set_errstring(module->ldb, "unicodePwd must have a value!\n");
 		return LDB_ERR_CONSTRAINT_VIOLATION;
 	}
 	if (lmAttr && (lmAttr->num_values == 0)) {
-		ldb_set_errstring(module->ldb, "lmPwdHash must have a value!\n");
+		ldb_set_errstring(module->ldb, "dBCSPwd must have a value!\n");
 		return LDB_ERR_CONSTRAINT_VIOLATION;
 	}
 
@@ -733,7 +733,7 @@
 		}
 	}
 
 	/* add also krb5 keys based on NT the hash (we might have ntPwdHash, but not the cleartext */
 	ret = add_krb5_keys_from_NThash(ac->module, msg, smb_krb5_context);
 	if (ret != LDB_SUCCESS) {
 		return ret;
@@ -809,7 +809,7 @@
 		return LDB_ERR_CONSTRAINT_VIOLATION;
 	}
 
 	/* If no part of this touches the sambaPassword OR ntPwdHash and/or lmPwdHash, then we don't
 	 * need to make any changes.  For password changes/set there should
 	 * be a 'delete' or a 'modify' on this attribute. */
 	/* If the only operation is the deletion of the passwords then go on */
@@ -56,7 +56,7 @@
  * calculate the password hashes.
  *
- * This function must not only update the ntPwdHash, lmPwdHash and
+ * This function must not only update the unicodePwd, dBCSPwd and
  * krb5Key fields, it must also atomicly increment the
  * msDS-KeyVersionNumber.  We should be in a transaction, so all this
@@ -733,7 +733,7 @@
 	}
 
-	/* add also krb5 keys based on NT the hash (we might have ntPwdHash, but not the cleartext */
+	/* add also krb5 keys based on NT the hash (we might have unicodePwd, but not the cleartext */
 	ret = add_krb5_keys_from_NThash(ac->module, msg, smb_krb5_context);
 	if (ret != LDB_SUCCESS) {
@@ -809,7 +809,7 @@
 	}
 
-	/* If no part of this touches the sambaPassword OR ntPwdHash and/or lmPwdHash, then we don't
+	/* If no part of this touches the sambaPassword OR unicodePwd and/or dBCSPwd, then we don't
 	 * need to make any changes.  For password changes/set there should
 	 * be a 'delete' or a 'modify' on this attribute. */



More information about the samba-cvs mailing list